@@ -38,12 +38,13 @@ class ExtractionVisitor(VariableVisitor):
 
     def __init__(self, period: Period, extraction_metadata_blocks: List[Tuple[LabelId, MetaDataBlock]],
                  half_lat_frame: int,
-                 half_lon_frame: int, dask_scheduler: str = 'single-threaded',
+                 half_lon_frame: int, has_to_round_coordinates: bool, dask_scheduler: str = 'single-threaded',
                  shape: ExtractionShape = ExtractionShape.SQUARE):
         self.__period: Period = period
         self.__extraction_metadata_blocks: List[Tuple[LabelId, MetaDataBlock]] = extraction_metadata_blocks
         self.__half_lat_frame: int = half_lat_frame
         self.__half_lon_frame: int = half_lon_frame
+        self.__has_to_round_coordinates = has_to_round_coordinates
         self.__dask_scheduler: str = dask_scheduler
         self.__shape: ExtractionShape = shape
         self.result: List[Tuple[LabelId, xr.DataArray, MetaDataBlock]] = list()
@@ -55,11 +56,13 @@ class ExtractionVisitor(VariableVisitor):
             # The order of extraction_data_list must be deterministic so as all the channel
             # match their extracted region line by line.
             for extraction_data in extraction_metadata_block:
-                extractor = ExtractionVisitor.__create_extractor(self.__shape)(datasets=datasets,
-                                                                               extraction_data=extraction_data,
-                                                                               half_lat_frame=self.__half_lat_frame,
-                                                                               half_lon_frame=self.__half_lon_frame,
-                                                                               dask_scheduler=self.__dask_scheduler)
+                extractor = ExtractionVisitor.__create_extractor(self.__shape)(
+                                                           datasets=datasets,
+                                                           extraction_data=extraction_data,
+                                                           half_lat_frame=self.__half_lat_frame,
+                                                           half_lon_frame=self.__half_lon_frame,
+                                                           has_to_round_coordinates=self.__has_to_round_coordinates,
+                                                           dask_scheduler=self.__dask_scheduler)
                 var.accept(extractor)
                 extracted_regions.append(extractor.get_result())
 
