@@ -24,7 +24,8 @@ class RegionExtractionVisitor(VariableVisitor):
     @abstractmethod
     def __init__(self, datasets: Mapping[VariableId, xr.Dataset],
                  extraction_data: Mapping[Union[Coordinate, TimeResolution], Union[int, float]],
-                 half_lat_frame: int, half_lon_frame: int, dask_scheduler: str = 'single-threaded'):
+                 half_lat_frame: int, half_lon_frame: int, has_to_round_coordinates: bool,
+                 dask_scheduler: str = 'single-threaded'):
         # Buffer of extracted regions: optimization for computed variables.
         # Computed variables may contain computed variables, recursively !
         self._extracted_regions: Dict[VariableId, xr.DataArray] = dict()
@@ -32,6 +33,7 @@ class RegionExtractionVisitor(VariableVisitor):
         self._extraction_data: Mapping[Union[Coordinate, TimeResolution], Union[int, float]] = extraction_data
         self._half_lat_frame: int = half_lat_frame
         self._half_lon_frame: int = half_lon_frame
+        self._has_to_round_coordinates: bool = has_to_round_coordinates
         self._dask_scheduler: str = dask_scheduler
         self._recursive_call_count: int = 0
         # noinspection PyTypeChecker
@@ -42,8 +44,9 @@ class SquareRegionExtractionVisitor(RegionExtractionVisitor):
 
     def __init__(self, datasets: Mapping[VariableId, xr.Dataset],
                  extraction_data: Mapping[Union[Coordinate, TimeResolution], Union[int, float]], half_lat_frame: int,
-                 half_lon_frame: int, dask_scheduler: str = 'single-threaded'):
-        super().__init__(datasets, extraction_data, half_lat_frame, half_lon_frame, dask_scheduler)
+                 half_lon_frame: int, has_to_round_coordinates: bool, dask_scheduler: str = 'single-threaded'):
+        super().__init__(datasets, extraction_data, half_lat_frame, half_lon_frame, has_to_round_coordinates,
+                         dask_scheduler)
 
     def __bootstrap(self, var: SingleLevelVariable) -> str:
         # month2d, day2d and hour2d are computed when calling convert_block_to_dict function from module
@@ -66,7 +69,8 @@ class SquareRegionExtractionVisitor(RegionExtractionVisitor):
                                                         time_netcdf_attr_name=var.time_netcdf_attr_name,
                                                         lat_netcdf_attr_name=var.lat_netcdf_attr_name,
                                                         lon_netcdf_attr_name=var.lon_netcdf_attr_name,
-                                                        has_to_round=True, lat_nb_decimal=var.lat_nb_decimal,
+                                                        has_to_round=self._has_to_round_coordinates,
+                                                        lat_nb_decimal=var.lat_nb_decimal,
                                                         lon_nb_decimal=var.lon_nb_decimal,
                                                         dask_scheduler=self._dask_scheduler)
             self._extracted_regions[var.str_id] = self._result
@@ -87,7 +91,8 @@ class SquareRegionExtractionVisitor(RegionExtractionVisitor):
                                                         time_netcdf_attr_name=var.time_netcdf_attr_name,
                                                         lat_netcdf_attr_name=var.lat_netcdf_attr_name,
                                                         lon_netcdf_attr_name=var.lon_netcdf_attr_name,
-                                                        has_to_round=True, lat_nb_decimal=var.lat_nb_decimal,
+                                                        has_to_round=self._has_to_round_coordinates,
+                                                        lat_nb_decimal=var.lat_nb_decimal,
                                                         lon_nb_decimal=var.lon_nb_decimal,
                                                         dask_scheduler=self._dask_scheduler)
             self._extracted_regions[var.str_id] = self._result
@@ -193,6 +198,7 @@ def __test_extraction(str_id, variable_parent_dir_path,
     import os.path as path
     from matplotlib import pyplot as plt
     import nxtensor.utils.file_utils as fu
+    has_to_round = True
     var = Variable.load(path.join(variable_parent_dir_path,
                         f"{str_id}{nxtensor.utils.naming_utils.NAME_SEPARATOR}{Variable.FILE_NAME_POSTFIX}"))
 
@@ -204,7 +210,7 @@ def __test_extraction(str_id, variable_parent_dir_path,
                 netcdf_file_path_dict.items()}
     extractor = SquareRegionExtractionVisitor(datasets=datasets, extraction_data=extraction_data,
                                               half_lat_frame=half_lat_frame, half_lon_frame=half_lon_frame,
-                                              dask_scheduler='single-threaded')
+                                              has_to_round_coordinates=has_to_round, dask_scheduler='single-threaded')
     var.accept(extractor)
     extracted_region = extractor.get_result()
     [dataset.close() for dataset in datasets.values()]
