@@ -20,6 +20,15 @@ def round_nearest(value, resolution, num_decimal):
     return round(round(value / resolution) * resolution, num_decimal)
 
 
+def round_coordinates(dataframe: pd.DataFrame, column_name: str, resolution: float, nb_decimal_to_round: int):
+    # Update the format of the coordinate.
+    def __round_coordinates(value):
+        rounded_value = round_nearest(value, resolution, nb_decimal_to_round)
+        return rounded_value
+
+    dataframe[column_name] = np.vectorize(__round_coordinates)(dataframe[column_name])
+
+
 def reformat_coordinates(dataframe: pd.DataFrame, column_name: str, from_format: CoordinateFormat,
                          to_format: CoordinateFormat, resolution: float, nb_decimal_to_round: int):
     coordinate_mapping = __get_convert_mapping(from_format, to_format, resolution)
@@ -64,15 +73,16 @@ def __compute_mapping(from_format, to_format, resolution, parent_mapping):
 
 
 def __generate_mapping_degrees_north_inc_to_dec(resolution):
-    values = __generate_float_range(-90, 90, resolution)
+    values = __generate_float_range(-90, 90+resolution, resolution)
     keys   = values
     return dict(zip(keys, values))
 
 
+# From -180° (included) / +180° (excluded) translated into 0° (included) / 360° (excluded).
 def __generate_mapping_degrees_east_m_180_to_0(resolution):
     dest_values = __generate_float_range(0, 360, resolution)
-    keys_1 = __generate_float_range(0, (180 + resolution), resolution)
-    keys_2 = __generate_float_range((-180 + resolution), 0, resolution)
+    keys_1 = __generate_float_range(0, 180, resolution)
+    keys_2 = __generate_float_range(-180, 0, resolution)
     result = dict()
     index = 0
     for key in keys_1:
@@ -84,14 +94,21 @@ def __generate_mapping_degrees_east_m_180_to_0(resolution):
     return result
 
 
+# Start included and stop NOT included.
+# If start < stop then stop - resolution is included.
+# If start > stop then stop + resolution is included.
 def __generate_float_range(start, stop, resolution):
     if resolution < 1:
         nb_decimal = len(str(resolution)) - 2  # -2 for the zero and the dot.
         factor = math.pow(10, nb_decimal)
-        int_range = range(int(start*factor), int(stop*factor), int(resolution*factor))
+
+        if start <= stop:
+            int_range = range(int(start * factor), int(stop * factor), int(resolution * factor))
+        else:
+            int_range = range(int(start * factor), int(stop * factor), int(resolution * factor * -1))
         result = list()
         for value in int_range:
-            result.append(value/100)
+            result.append(value / factor)
         return result
     else:
         return range(start, stop, resolution)
