@@ -7,7 +7,7 @@ Created on Fri Jun 5 10:00:00 2020
 @author: sebastien@gardoll.fr
 """
 
-from typing import Tuple, Iterable, Sequence
+from typing import Tuple, Iterable, Sequence, Callable
 
 from nxtensor.core.types import LabelId, Period
 
@@ -42,6 +42,15 @@ __STAT_FILENAME_TEMPLATE: str = '{}' + NAME_SEPARATOR + 'stats.' + fu.CSV_FILE_E
 __PREPROCESSING_FILENAME_TEMPLATE: str = '{}' + NAME_SEPARATOR + 'preprocessing.' + fu.PICKLE_FILE_EXTENSION
 
 
+def compute_another_name(base: str, test_function: Callable[[str], bool]) -> str:
+    result = base
+    count = 2
+    while not test_function(result):
+        result = f'{base}{count}'
+        count += 1
+    return result
+
+
 def compute_data_meta_data_file_path(str_id: str, parent_dir_path: str, *other_filename_prefixes: str)\
         -> Tuple[str, str]:
     data_file_template_path, metadata_file_template_path = \
