@@ -73,12 +73,14 @@ class __SquareExtractionProcessor(chan_xtract.BlockProcessor):
         half_lat_frame = int((self.__extraction_conf.y_size * self.__variable.lat_resolution)/2)
         half_lon_frame = int((self.__extraction_conf.y_size * self.__variable.lon_resolution)/2)
 
-        extractor: ExtractionVisitor = ExtractionVisitor(period=period,
-                                                         extraction_metadata_blocks=extraction_metadata_blocks,
-                                                         half_lat_frame=half_lat_frame,
-                                                         half_lon_frame=half_lon_frame,
-                                                         dask_scheduler=self.__extraction_conf.dask_scheduler,
-                                                         shape=self.__extraction_conf.extraction_shape)
+        extractor: ExtractionVisitor = ExtractionVisitor(
+                                               period=period,
+                                               extraction_metadata_blocks=extraction_metadata_blocks,
+                                               half_lat_frame=half_lat_frame,
+                                               half_lon_frame=half_lon_frame,
+                                               has_to_round_coordinates=self.__extraction_conf.has_to_round_coordinates,
+                                               dask_scheduler=self.__extraction_conf.dask_scheduler,
+                                               shape=self.__extraction_conf.extraction_shape)
         self.__variable.accept(extractor)
         result: Tuple[str, List[Tuple[LabelId, xr.DataArray, MetaDataBlock]]] = \
             (self.__extraction_conf.blocks_dir_path, extractor.get_result())
